#include <gtk/gtk.h>

GtkWidget *hscale, *vscale;

function cb_pos_menu_select(item)
%    /* Set the value position on both scale widgets */
    gtk_scale_set_value_pos (GTK_SCALE (hscale), pos);
    gtk_scale_set_value_pos (GTK_SCALE (vscale), pos);
end

function cb_update_menu_select(item)
%    /* Set the update policy for both scale widgets */
    gtk_range_set_update_policy (GTK_RANGE (hscale), policy);
    gtk_range_set_update_policy (GTK_RANGE (vscale), policy);
end

function cb_digits_scale( GtkAdjustment *adj )
%    /* Set the number of decimal places to which adj->value is rounded */
    gtk_scale_set_digits (GTK_SCALE (hscale), (gint) adj->value);
    gtk_scale_set_digits (GTK_SCALE (vscale), (gint) adj->value);
end

function cb_page_size(get)
%    /* Set the page size and page increment size of the sample
%     * adjustment to the value specified by the "Page Size" scale */
    set->page_size = get->value;
    set->page_increment = get->value;
    /* This sets the adjustment and makes it emit the "changed" signal to 
       reconfigure all the widgets that are attached to this signal.  */
    gtk_adjustment_set_value (set, CLAMP (set->value,
					  set->lower,
					  (set->upper - set->page_size)));
end

function cb_draw_value( GtkToggleButton *button )
%    /* Turn the value display on the scale widgets off or on depending
%     *  on the state of the checkbutton */
    gtk_scale_set_draw_value((hscale),gtk_toggle_button_get_active(button));
    gtk_scale_set_draw_value((vscale),gtk_toggle_button_get_active(button));
end    

%/* Convenience functions */

function item=make_menu_item (name,callback)
    item = gtk_menu_item_new_with_label(name);
    g_signal_connect (item,"activate",callback);
    gtk_widget_show (item);
    return 
end

function scale_set_default_values(scale)
    GTK_UPDATE_CONTINUOUS=0
    GTK_POS_TOP=2
    TRUE=1
    gtk_range_set_update_policy (scale,GTK_UPDATE_CONTINUOUS);
    gtk_scale_set_digits (scale, 1);
    gtk_scale_set_value_pos (scale, GTK_POS_TOP);
    gtk_scale_set_draw_value (scale, TRUE);
end

/* makes the sample window */

function window=create_range_controls( void )
    window=0;
    box1=0;box2=0; box3=0;
    button=0;
    scrollbar=0;
    separator=0;
    opt=0;menu=0;item=0;
    label=0;
    scale=0;
    adj1=0;adj2=0;
    
    NULL=0
    TRUE=1
    FALSE=0

    /* Standard window-creating stuff */
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    g_signal_connect ((window), "destroy","gtk_main_quit")
    gtk_window_set_title ((window), "range controls");

    box1 = gtk_vbox_new (FALSE, 0);
    gtk_container_add (GTK_CONTAINER (window), box1);
    gtk_widget_show (box1);

    box2 = gtk_hbox_new (FALSE, 10);
    gtk_container_set_border_width (box2, 10);
    gtk_box_pack_start ((box1), box2, TRUE, TRUE, 0);
    gtk_widget_show (box2);

%    /* value, lower, upper, step_increment, page_increment, page_size */
%    /* Note that the page_size value only makes a difference for
%     * scrollbar widgets, and the highest value you'll get is actually
%     * (upper - page_size). */
    adj1 = gtk_adjustment_new (0.0, 0.0, 101.0, 0.1, 1.0, 1.0);
  
    vscale = gtk_vscale_new ((adj1));
    scale_set_default_values ((vscale));
    gtk_box_pack_start ((box2), vscale, TRUE, TRUE, 0);
    gtk_widget_show (vscale);

    box3 = gtk_vbox_new (FALSE, 10);
    gtk_box_pack_start ((box2), box3, TRUE, TRUE, 0);
    gtk_widget_show (box3);

    /* Reuse the same adjustment */
    hscale = gtk_hscale_new ((adj1));
    gtk_widget_set_size_request((hscale), 200, -1);
    scale_set_default_values ((hscale));
    gtk_box_pack_start ((box3), hscale, TRUE, TRUE, 0);
    gtk_widget_show (hscale);

    /* Reuse the same adjustment again */
    scrollbar = gtk_hscrollbar_new ((adj1));
    /* Notice how this causes the scales to always be updated
     * continuously when the scrollbar is moved */
    gtk_range_set_update_policy ((scrollbar), 
                                 GTK_UPDATE_CONTINUOUS);
    gtk_box_pack_start ((box3), scrollbar, TRUE, TRUE, 0);
    gtk_widget_show (scrollbar);

    box2 = gtk_hbox_new (FALSE, 10);
    gtk_container_set_border_width ((box2), 10);
    gtk_box_pack_start ((box1), box2, TRUE, TRUE, 0);
    gtk_widget_show (box2);

    /* A checkbutton to control whether the value is displayed or not */
    button = gtk_check_button_new_with_label("Display value on scale widgets");
    gtk_toggle_button_set_active ((button), TRUE);
    g_signal_connect ((button), "toggled",
                      "cb_draw_value")
    gtk_box_pack_start ( (box2), button, TRUE, TRUE, 0);
    gtk_widget_show (button);
  
    box2 = gtk_hbox_new (FALSE, 10);
    gtk_container_set_border_width ((box2), 10);

    /* An option menu to change the position of the value */
    label = gtk_label_new ("Scale Value Position:");
    gtk_box_pack_start (GTK_BOX (box2), label, FALSE, FALSE, 0);
    gtk_widget_show (label);
  
    opt = gtk_option_menu_new ();
    menu = gtk_menu_new ();

    item = make_menu_item ("Top",
                           "cb_pos_menu_select");
    gtk_menu_shell_append ((menu), item);
  
    item = make_menu_item ("Bottom","cb_pos_menu_select")                          
    gtk_menu_shell_append ((menu), item);
  
    item = make_menu_item ("Left", "cb_pos_menu_select")
    gtk_menu_shell_append ((menu), item);
  
    item = make_menu_item ("Right","cb_pos_menu_select")
    gtk_menu_shell_append ((menu), item);
  
    gtk_option_menu_set_menu ((opt), menu);
    gtk_box_pack_start ((box2), opt, TRUE, TRUE, 0);
    gtk_widget_show (opt);

    gtk_box_pack_start ((box1), box2, TRUE, TRUE, 0);
    gtk_widget_show (box2);

    box2 = gtk_hbox_new (FALSE, 10);
    gtk_container_set_border_width ((box2),10);

    /* Yet another option menu, this time for the update policy of the
     * scale widgets */
    label = gtk_label_new ("Scale Update Policy:");
    gtk_box_pack_start ((box2), label, FALSE, FALSE, 0);
    gtk_widget_show (label);
  
    opt = gtk_option_menu_new ();
    menu = gtk_menu_new ();
  
    item = make_menu_item ("Continuous",
                           "cb_update_menu_select")
    gtk_menu_shell_append ((menu), item);
  
    item = make_menu_item ("Discontinuous",
                           "cb_update_menu_select")
    gtk_menu_shell_append ((menu), item);
  
    item = make_menu_item ("Delayed",
                           "cb_update_menu_select")
    gtk_menu_shell_append ((menu), item);
  
    gtk_option_menu_set_menu ((opt), menu);
    gtk_box_pack_start ((box2), opt, TRUE, TRUE, 0);
    gtk_widget_show (opt);
  
    gtk_box_pack_start ((box1), box2, TRUE, TRUE, 0);
    gtk_widget_show (box2);

    box2 = gtk_hbox_new (FALSE, 10);
    gtk_container_set_border_width ((box2), 10);
  
    /* An HScale widget for adjusting the number of digits on the
     * sample scales. */
    label = gtk_label_new ("Scale Digits:");
    gtk_box_pack_start ((box2),label, FALSE, FALSE, 0);
    gtk_widget_show (label);

    adj2 = gtk_adjustment_new (1.0, 0.0, 5.0, 1.0, 1.0, 0.0);
    g_signal_connect ((adj2), "value_changed","cb_digits_scale")
    scale = gtk_hscale_new ((adj2));
    gtk_scale_set_digits ((scale), 0);
    gtk_box_pack_start ((box2), scale, TRUE, TRUE, 0);
    gtk_widget_show (scale);

    gtk_box_pack_start ((box1), box2, TRUE, TRUE, 0);
    gtk_widget_show (box2);
  
    box2 = gtk_hbox_new (FALSE, 10);
    gtk_container_set_border_width ((box2), 10);
  
    /* And, one last HScale widget for adjusting the page size of the
     * scrollbar. */
    label = gtk_label_new ("Scrollbar Page Size:");
    gtk_box_pack_start ((box2), label, FALSE, FALSE, 0);
    gtk_widget_show (label);

    adj2 = gtk_adjustment_new (1.0, 1.0, 101.0, 1.0, 1.0, 0.0);
    g_signal_connect ( (adj2), "value_changed",
                      (cb_page_size), (gpointer) adj1);
    scale = gtk_hscale_new ( (adj2));
    gtk_scale_set_digits ( (scale), 0);
    gtk_box_pack_start ((box2), scale, TRUE, TRUE, 0);
    gtk_widget_show (scale);

    gtk_box_pack_start ((box1), box2, TRUE, TRUE, 0);
    gtk_widget_show (box2);

    separator = gtk_hseparator_new ();
    gtk_box_pack_start ((box1), separator, FALSE, TRUE, 0);
    gtk_widget_show (separator);

    box2 = gtk_vbox_new (FALSE, 10);
    gtk_container_set_border_width ( (box2), 10);
    gtk_box_pack_start ( (box1), box2, FALSE, TRUE, 0);
    gtk_widget_show (box2);

    button = gtk_button_new_with_label ("Quit");
    g_signal_connect((button),"clicked",
		     ("gtk_main_quit"))
    gtk_box_pack_start ( (box2), button, TRUE, TRUE, 0);
    %gtk_widget_grab_default (button);
    gtk_widget_show (button);
    gtk_widget_show (window);
end

int main( int   argc,
          char *argv[] )
{
    gtk_init (&argc, &argv);

    create_range_controls ();

    gtk_main ();

    return 0;
}

#!/usr/bin/octave -q
%(C)FEB 2005 DHRUVKARAN N. MEHTA
function hello(widget)
        disp("Hello World\n");
end

function x=delete_event(widget,event)

%    /* If you return FALSE in the "delete_event" signal handler,
%     * GTK will emit the "destroy" signal. Returning TRUE means
%     * you don't want the window to be destroyed.
%     * This is useful for popping up 'are you sure you want to quit?'
%     * type dialogs. */

    printf("delete event occurred\n");

%    /* Change TRUE to FALSE and the main window will be destroyed with
%     * a "delete_event". */
    x=1;
    return;
end

%/* Another callback */
function destroy(widget)
    gtk_main_quit ();
end

function main()
 %   /* GtkWidget is the storage type for widgets */
  gtk()
    
  %  /* This is called in all GTK applications. Arguments are parsed
  %  * from the command line and are returned to the application. */
	       gtk_init ();
    
  %  /* create a new window */
    GTK_WINDOW_TOPLEVEL=0;
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
  %  /* When the window is given the "delete_event" signal (this is given
  %   * by the window manager, usually by the "close" option, or on the
  %   * titlebar), we ask it to call the delete_event () function
  %   * as defined above. The data passed to the callback
  %   * function is NULL and is ignored in the callback function. */
    g_signal_connect ( (window), "delete_event",
		       " delete_event", 0);
    
  %  /* Here we connect the "destroy" event to a signal handler.  
  %   * This event occurs when we call gtk_widget_destroy() on the window,
  %   * or if we return FALSE in the "delete_event" callback. */
    g_signal_connect ( (window), "destroy",
		       "destroy", 0);
    
  %  /* Sets the border width of the window. */
    gtk_container_set_border_width ( (window), 10);
    
  %  /* Creates a new button with the label "Hello World". */
    button = gtk_button_new_with_label ("Hello World");
    
  %  /* When the button receives the "clicked" signal, it will call the
  %   * function hello() passing it NULL as its argument.  The hello()
  %   * function is defined above. */
    g_signal_connect ( (button), "clicked",
		       "hello", 0);
    
  %  /* This will cause the window to be destroyed by calling
  %   * gtk_widget_destroy(window) when "clicked".  Again, the destroy
  %   * signal could come from here, or the window manager. */
    g_signal_connect( (button), "clicked",
			       "gtk_widget_destroy");
    
  %  /* This packs the button into the window (a gtk container). */
    gtk_container_add ( (window), button);
    
  %  /* The final step is to display this newly created widget. */
    gtk_widget_show (button);
    
  %  /* and the window */
    gtk_widget_show (window);
    
  %  /* All GTK applications must have a gtk_main(). Control ends here
  %   * and waits for an event to occur (like a key press or
  %   * mouse event). */
    gtk_main ();
    
    return;
end
    main();
